<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>KWin::SplitMenu</name>
    <message>
        <source>Tile window to left of screen</source>
        <translation>將視窗拼貼到左側</translation>
    </message>
    <message>
        <source>Tile window to right of screen</source>
        <translation>將視窗拼貼到右側</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation>最大化</translation>
    </message>
    <message>
        <source>Unmaximize</source>
        <translation>還原</translation>
    </message>
</context>
</TS>